@@ -1,13 +1,16 @@
 # Created by  Sunkyeong Lee
 # email : sunkyong9768@gmail.com
 
+from copy import Error
 from .actModuler import *
 from .actRunner import *
 import time
 
 
-def Retrive_FirstLevel(start_date, end_date, period, jsonLocation, tbColumn, dbTableName, epp, site_code_rs):
-    
+def Retrive_FirstLevel(start_date, end_date, period, jsonLocation, tbColumn, dbTableName, epp, site_code_rs, limit):
+    if limit > 1000:
+        raise Error("limit은 0 ~ 1000 사이 값으로 넣어주세요")
+
     dateCaller = dateGenerator(start_date, end_date, period)
     if_site_code = checkSiteCode(readJson(jsonLocation)["dimension"])
     
@@ -20,10 +23,10 @@ def Retrive_FirstLevel(start_date, end_date, period, jsonLocation, tbColumn, dbT
         while True:
             try:
                 start = time.time()
-                jsonToDb(startDate[i], endDate[i], period, jsonLocation, tbColumn, dbTableName, epp, if_site_code, site_code_rs)
+                jsonToDb(startDate[i], endDate[i], period, jsonLocation, tbColumn, dbTableName, epp, if_site_code, site_code_rs, limit)
                 timeSec = round(time.time() - start, 2)
                 print("Time took: ", timeSec, "sec")
-
+  
             except KeyError:
                 print("Server Error Occurred")
                 continue
@@ -38,6 +41,9 @@ def Retrive_SecondLevel(start_date, end_date, period, jsonLocation, jsonLocation
     dateCaller = dateGenerator(start_date, end_date, period)
     if_site_code = checkSiteCode(readJson(jsonLocation)["dimension"])
 
+    if returnRsID(jsonLocation) == "sssamsungnewus":
+        if_site_code = True
+
     site_code_rs = False
     tbColumn = tbColumnGenerator(tbColumn, if_site_code, True, False, site_code_rs)
     
